@@ -4,7 +4,7 @@ import logging
 from pygogogate2 import Gogogate2API as pygogogate2
 import voluptuous as vol
 
-from homeassistant.components.cover import SUPPORT_CLOSE, SUPPORT_OPEN, CoverDevice
+from homeassistant.components.cover import SUPPORT_CLOSE, SUPPORT_OPEN, CoverEntity
 from homeassistant.const import (
     CONF_IP_ADDRESS,
     CONF_NAME,
@@ -51,15 +51,13 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     except (TypeError, KeyError, NameError, ValueError) as ex:
         _LOGGER.error("%s", ex)
         hass.components.persistent_notification.create(
-            "Error: {}<br />"
-            "You will need to restart hass after fixing."
-            "".format(ex),
+            (f"Error: {ex}<br />You will need to restart hass after fixing."),
             title=NOTIFICATION_TITLE,
             notification_id=NOTIFICATION_ID,
         )
 
 
-class MyGogogate2Device(CoverDevice):
+class MyGogogate2Device(CoverEntity):
     """Representation of a Gogogate2 cover."""
 
     def __init__(self, mygogogate2, device, name):
