@@ -24,7 +24,7 @@ from homeassistant.const import (
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 
-from .const import CONF_BASE_PATH, CONF_UUID
+from .const import CONF_BASE_PATH, CONF_SERIAL, CONF_UUID
 from .const import DOMAIN  # pylint: disable=unused-import
 
 _LOGGER = logging.getLogger(__name__)
@@ -47,7 +47,7 @@ async def validate_input(hass: HomeAssistantType, data: dict) -> Dict[str, Any]:
 
     printer = await ipp.printer()
 
-    return {CONF_UUID: printer.info.uuid}
+    return {CONF_SERIAL: printer.info.serial, CONF_UUID: printer.info.uuid}
 
 
 class IPPFlowHandler(ConfigFlow, domain=DOMAIN):
@@ -83,20 +83,28 @@ class IPPFlowHandler(ConfigFlow, domain=DOMAIN):
             _LOGGER.debug("IPP Error", exc_info=True)
             return self.async_abort(reason="ipp_error")
 
-        user_input[CONF_UUID] = info[CONF_UUID]
+        unique_id = user_input[CONF_UUID] = info[CONF_UUID]
 
-        await self.async_set_unique_id(user_input[CONF_UUID])
+        if unique_id is None and info[CONF_SERIAL] is not None:
+            _LOGGER.debug(
+                "Printer UUID is missing from IPP response. Falling back to IPP serial number"
+            )
+            unique_id = info[CONF_SERIAL]
+        elif unique_id is None:
+            _LOGGER.debug("Unable to determine unique id from IPP response")
+
+        await self.async_set_unique_id(unique_id)
         self._abort_if_unique_id_configured(updates={CONF_HOST: user_input[CONF_HOST]})
 
         return self.async_create_entry(title=user_input[CONF_HOST], data=user_input)
 
     async def async_step_zeroconf(self, discovery_info: ConfigType) -> Dict[str, Any]:
         """Handle zeroconf discovery."""
-        # Hostname is format: EPSON123456.local.
-        host = discovery_info["hostname"].rstrip(".")
-        port = discovery_info["port"]
-        name, _ = host.rsplit(".")
-        tls = discovery_info["type"] == "_ipps._tcp.local."
+        port = discovery_info[CONF_PORT]
+        zctype = discovery_info["type"]
+        name = discovery_info[CONF_NAME].replace(f".{zctype}", "")
+        tls = zctype == "_ipps._tcp.local."
+        base_path = discovery_info["properties"].get("rp", "ipp/print")
 
         # pylint: disable=no-member # https://github.com/PyCQA/pylint/issues/3167
         self.context.update({"title_placeholders": {"name": name}})
@@ -107,8 +115,7 @@ class IPPFlowHandler(ConfigFlow, domain=DOMAIN):
                 CONF_PORT: port,
                 CONF_SSL: tls,
                 CONF_VERIFY_SSL: False,
-                CONF_BASE_PATH: "/"
-                + discovery_info["properties"].get("rp", "ipp/print"),
+                CONF_BASE_PATH: f"/{base_path}",
                 CONF_NAME: name,
                 CONF_UUID: discovery_info["properties"].get("UUID"),
             }
@@ -130,12 +137,29 @@ class IPPFlowHandler(ConfigFlow, domain=DOMAIN):
             _LOGGER.debug("IPP Error", exc_info=True)
             return self.async_abort(reason="ipp_error")
 
-        if info[CONF_UUID] is not None:
-            self.discovery_info[CONF_UUID] = info[CONF_UUID]
+        unique_id = self.discovery_info[CONF_UUID]
+        if unique_id is None and info[CONF_UUID] is not None:
+            _LOGGER.debug(
+                "Printer UUID is missing from discovery info. Falling back to IPP UUID"
+            )
+            unique_id = self.discovery_info[CONF_UUID] = info[CONF_UUID]
+        elif unique_id is None and info[CONF_SERIAL] is not None:
+            _LOGGER.debug(
+                "Printer UUID is missing from discovery info and IPP response. Falling back to IPP serial number"
+            )
+            unique_id = info[CONF_SERIAL]
+        elif unique_id is None:
+            _LOGGER.debug(
+                "Unable to determine unique id from discovery info and IPP response"
+            )
+            return self.async_abort(reason="unique_id_required")
 
-        await self.async_set_unique_id(self.discovery_info[CONF_UUID])
+        await self.async_set_unique_id(unique_id)
         self._abort_if_unique_id_configured(
-            updates={CONF_HOST: self.discovery_info[CONF_HOST]}
+            updates={
+                CONF_HOST: self.discovery_info[CONF_HOST],
+                CONF_NAME: self.discovery_info[CONF_NAME],
+            },
         )
 
         return await self.async_step_zeroconf_confirm()
