@@ -1,7 +1,7 @@
 """Constants used by Home Assistant components."""
 MAJOR_VERSION = 0
-MINOR_VERSION = 108
-PATCH_VERSION = "8"
+MINOR_VERSION = 110
+PATCH_VERSION = "0"
 __short_version__ = f"{MAJOR_VERSION}.{MINOR_VERSION}"
 __version__ = f"{__short_version__}.{PATCH_VERSION}"
 REQUIRED_PYTHON_VER = (3, 7, 0)
@@ -34,6 +34,7 @@ CONF_AFTER = "after"
 CONF_ALIAS = "alias"
 CONF_API_KEY = "api_key"
 CONF_API_VERSION = "api_version"
+CONF_ARMING_TIME = "arming_time"
 CONF_AT = "at"
 CONF_AUTH_MFA_MODULES = "auth_mfa_modules"
 CONF_AUTH_PROVIDERS = "auth_providers"
@@ -87,6 +88,7 @@ CONF_EVENT = "event"
 CONF_EVENT_DATA = "event_data"
 CONF_EVENT_DATA_TEMPLATE = "event_data_template"
 CONF_EXCLUDE = "exclude"
+CONF_EXTERNAL_URL = "external_url"
 CONF_FILE_PATH = "file_path"
 CONF_FILENAME = "filename"
 CONF_FOR = "for"
@@ -101,6 +103,7 @@ CONF_ICON = "icon"
 CONF_ICON_TEMPLATE = "icon_template"
 CONF_ID = "id"
 CONF_INCLUDE = "include"
+CONF_INTERNAL_URL = "internal_url"
 CONF_IP_ADDRESS = "ip_address"
 CONF_LATITUDE = "latitude"
 CONF_LIGHTS = "lights"
@@ -183,6 +186,7 @@ EVENT_COMPONENT_LOADED = "component_loaded"
 EVENT_CORE_CONFIG_UPDATE = "core_config_updated"
 EVENT_HOMEASSISTANT_CLOSE = "homeassistant_close"
 EVENT_HOMEASSISTANT_START = "homeassistant_start"
+EVENT_HOMEASSISTANT_STARTED = "homeassistant_started"
 EVENT_HOMEASSISTANT_STOP = "homeassistant_stop"
 EVENT_HOMEASSISTANT_FINAL_WRITE = "homeassistant_final_write"
 EVENT_LOGBOOK_ENTRY = "logbook_entry"
@@ -344,14 +348,22 @@ ATTR_TEMPERATURE = "temperature"
 # #### UNITS OF MEASUREMENT ####
 # Power units
 POWER_WATT = "W"
+POWER_KILO_WATT = f"k{POWER_WATT}"
+
+# Voltage units
+VOLT = "V"
 
 # Energy units
-ENERGY_KILO_WATT_HOUR = "kWh"
-ENERGY_WATT_HOUR = "Wh"
+ENERGY_WATT_HOUR = f"{POWER_WATT}h"
+ENERGY_KILO_WATT_HOUR = f"k{ENERGY_WATT_HOUR}"
+
+# Degree units
+DEGREE = "°"
 
 # Temperature units
-TEMP_CELSIUS = "°C"
-TEMP_FAHRENHEIT = "°F"
+TEMP_CELSIUS = f"{DEGREE}C"
+TEMP_FAHRENHEIT = f"{DEGREE}F"
+TEMP_KELVIN = f"{DEGREE}K"
 
 # Time units
 TIME_MICROSECONDS = "μs"
@@ -374,6 +386,10 @@ LENGTH_FEET: str = "ft"
 LENGTH_YARD: str = "yd"
 LENGTH_MILES: str = "mi"
 
+# Frequency units
+FREQUENCY_HERTZ = "Hz"
+FREQUENCY_GIGAHERTZ = f"G{FREQUENCY_HERTZ}"
+
 # Pressure units
 PRESSURE_PA: str = "Pa"
 PRESSURE_HPA: str = "hPa"
@@ -402,11 +418,15 @@ MASS_MICROGRAMS = "µg"
 MASS_OUNCES: str = "oz"
 MASS_POUNDS: str = "lb"
 
+# Conductivity units
+CONDUCTIVITY: str = f"µS/{LENGTH_CENTIMETERS}"
+
 # UV Index units
-UNIT_UV_INDEX: str = "UV index"
+UV_INDEX: str = "UV index"
 
 # Percentage units
 UNIT_PERCENTAGE = "%"
+
 # Irradiation units
 IRRADIATION_WATTS_PER_SQUARE_METER = f"{POWER_WATT}/{AREA_SQUARE_METERS}"
 
@@ -527,6 +547,7 @@ HTTP_CREATED = 201
 HTTP_MOVED_PERMANENTLY = 301
 HTTP_BAD_REQUEST = 400
 HTTP_UNAUTHORIZED = 401
+HTTP_FORBIDDEN = 403
 HTTP_NOT_FOUND = 404
 HTTP_METHOD_NOT_ALLOWED = 405
 HTTP_UNPROCESSABLE_ENTITY = 422
