@@ -2,7 +2,17 @@
 import asyncio
 from functools import partial, wraps
 import logging
-from typing import Callable
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Set,
+    Tuple,
+)
 
 import voluptuous as vol
 
@@ -22,13 +32,17 @@ from homeassistant.exceptions import (
     Unauthorized,
     UnknownUser,
 )
-from homeassistant.helpers import template, typing
+from homeassistant.helpers import template
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.typing import HomeAssistantType
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType, TemplateVarsType
 from homeassistant.loader import async_get_integration, bind_hass
 from homeassistant.util.yaml import load_yaml
 from homeassistant.util.yaml.loader import JSON_TYPE
 
+if TYPE_CHECKING:
+    from homeassistant.helpers.entity import Entity  # noqa
+
+
 # mypy: allow-untyped-defs, no-check-untyped-defs
 
 CONF_SERVICE_ENTITY_ID = "entity_id"
@@ -42,8 +56,12 @@ SERVICE_DESCRIPTION_CACHE = "service_description_cache"
 
 @bind_hass
 def call_from_config(
-    hass, config, blocking=False, variables=None, validate_config=True
-):
+    hass: HomeAssistantType,
+    config: ConfigType,
+    blocking: bool = False,
+    variables: TemplateVarsType = None,
+    validate_config: bool = True,
+) -> None:
     """Call a service based on a config hash."""
     asyncio.run_coroutine_threadsafe(
         async_call_from_config(hass, config, blocking, variables, validate_config),
@@ -53,8 +71,13 @@ def call_from_config(
 
 @bind_hass
 async def async_call_from_config(
-    hass, config, blocking=False, variables=None, validate_config=True, context=None
-):
+    hass: HomeAssistantType,
+    config: ConfigType,
+    blocking: bool = False,
+    variables: TemplateVarsType = None,
+    validate_config: bool = True,
+    context: Optional[ha.Context] = None,
+) -> None:
     """Call a service based on a config hash."""
     try:
         parms = async_prepare_call_from_config(hass, config, variables, validate_config)
@@ -68,7 +91,12 @@ async def async_call_from_config(
 
 @ha.callback
 @bind_hass
-def async_prepare_call_from_config(hass, config, variables=None, validate_config=False):
+def async_prepare_call_from_config(
+    hass: HomeAssistantType,
+    config: ConfigType,
+    variables: TemplateVarsType = None,
+    validate_config: bool = False,
+) -> Tuple[str, str, Dict[str, Any]]:
     """Prepare to call a service based on a config hash."""
     if validate_config:
         try:
@@ -113,7 +141,9 @@ def async_prepare_call_from_config(hass, config, variables=None, validate_config
 
 
 @bind_hass
-def extract_entity_ids(hass, service_call, expand_group=True):
+def extract_entity_ids(
+    hass: HomeAssistantType, service_call: ha.ServiceCall, expand_group: bool = True
+) -> Set[str]:
     """Extract a list of entity ids from a service call.
 
     Will convert group entity ids to the entity ids it represents.
@@ -124,7 +154,12 @@ def extract_entity_ids(hass, service_call, expand_group=True):
 
 
 @bind_hass
-async def async_extract_entities(hass, entities, service_call, expand_group=True):
+async def async_extract_entities(
+    hass: HomeAssistantType,
+    entities: Iterable["Entity"],
+    service_call: ha.ServiceCall,
+    expand_group: bool = True,
+) -> List["Entity"]:
     """Extract a list of entity objects from a service call.
 
     Will convert group entity ids to the entity ids it represents.
@@ -158,7 +193,9 @@ async def async_extract_entities(hass, entities, service_call, expand_group=True
 
 
 @bind_hass
-async def async_extract_entity_ids(hass, service_call, expand_group=True):
+async def async_extract_entity_ids(
+    hass: HomeAssistantType, service_call: ha.ServiceCall, expand_group: bool = True
+) -> Set[str]:
     """Extract a list of entity ids from a service call.
 
     Will convert group entity ids to the entity ids it represents.
@@ -166,7 +203,7 @@ async def async_extract_entity_ids(hass, service_call, expand_group=True):
     entity_ids = service_call.data.get(ATTR_ENTITY_ID)
     area_ids = service_call.data.get(ATTR_AREA_ID)
 
-    extracted = set()
+    extracted: Set[str] = set()
 
     if entity_ids in (None, ENTITY_MATCH_NONE) and area_ids in (
         None,
@@ -226,7 +263,9 @@ async def _load_services_file(hass: HomeAssistantType, domain: str) -> JSON_TYPE
 
 
 @bind_hass
-async def async_get_all_descriptions(hass):
+async def async_get_all_descriptions(
+    hass: HomeAssistantType,
+) -> Dict[str, Dict[str, Any]]:
     """Return descriptions (i.e. user documentation) for all service calls."""
     descriptions_cache = hass.data.setdefault(SERVICE_DESCRIPTION_CACHE, {})
     format_cache_key = "{}.{}".format
@@ -253,7 +292,7 @@ async def async_get_all_descriptions(hass):
             loaded[domain] = content
 
     # Build response
-    descriptions = {}
+    descriptions: Dict[str, Dict[str, Any]] = {}
     for domain in services:
         descriptions[domain] = {}
 
@@ -281,7 +320,9 @@ async def async_get_all_descriptions(hass):
 
 @ha.callback
 @bind_hass
-def async_set_service_schema(hass, domain, service, schema):
+def async_set_service_schema(
+    hass: HomeAssistantType, domain: str, service: str, schema: Dict[str, Any]
+) -> None:
     """Register a description for a service."""
     hass.data.setdefault(SERVICE_DESCRIPTION_CACHE, {})
 
@@ -454,7 +495,7 @@ async def _handle_entity_call(hass, entity, func, data, context):
 @bind_hass
 @ha.callback
 def async_register_admin_service(
-    hass: typing.HomeAssistantType,
+    hass: HomeAssistantType,
     domain: str,
     service: str,
     service_func: Callable,
@@ -504,19 +545,25 @@ def verify_domain_control(hass: HomeAssistantType, domain: str) -> Callable:
 
             reg = await hass.helpers.entity_registry.async_get_registry()
 
+            authorized = False
+
             for entity in reg.entities.values():
                 if entity.platform != domain:
                     continue
 
                 if user.permissions.check_entity(entity.entity_id, POLICY_CONTROL):
-                    return await service_handler(call)
+                    authorized = True
+                    break
 
-            raise Unauthorized(
-                context=call.context,
-                permission=POLICY_CONTROL,
-                user_id=call.context.user_id,
-                perm_category=CAT_ENTITIES,
-            )
+            if not authorized:
+                raise Unauthorized(
+                    context=call.context,
+                    permission=POLICY_CONTROL,
+                    user_id=call.context.user_id,
+                    perm_category=CAT_ENTITIES,
+                )
+
+            return await service_handler(call)
 
         return check_permissions
 
